@@ -1,12 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2017-2021 Pytroll developers
+# Copyright (c) 2017-2022 Pytroll developers
 #
-# Author(s):
-#
-#   Adam Dybbroe <adam.dybbroe@smhi.se>
-#   Simon Proud
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,18 +18,18 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """Unit testing the generic rsr hdf5 reader."""
-
+import contextlib
 import os.path
-import numpy as np
-import xarray as xr
 import unittest
 from unittest.mock import patch
+
+import numpy as np
 import pytest
+import xarray as xr
 
 from pyspectral.rsr_reader import RelativeSpectralResponse, RSRDict
-from pyspectral.utils import WAVE_NUMBER
-from pyspectral.utils import RSR_DATA_VERSION
 from pyspectral.tests.unittest_helpers import assertNumpyArraysEqual
+from pyspectral.utils import RSR_DATA_VERSION, RSR_DATA_VERSION_FILENAME, WAVE_NUMBER
 
 TEST_RSR = {'20': {}, }
 TEST_RSR['20']['det-1'] = {}
@@ -87,8 +83,12 @@ class TestRsrReader(unittest.TestCase):
     @patch('pyspectral.rsr_reader.RelativeSpectralResponse.load')
     @patch('pyspectral.rsr_reader.download_rsr')
     @patch('pyspectral.rsr_reader.RelativeSpectralResponse._get_rsr_data_version')
-    def test_rsr_response(self, get_rsr_version, download_rsr, load, isfile, exists):
-        """Test the RelativeSpectralResponse class initialisation."""
+    def test_get_rsr_from_platform_name_and_instrument(self, get_rsr_version,
+                                                       download_rsr, load, isfile, exists):
+        """Test the RelativeSpectralResponse class initialisation.
+
+        Test getting the rsr from platform_name and instrument.
+        """
         load.return_code = None
         download_rsr.return_code = None
         isfile.return_code = True
@@ -97,29 +97,10 @@ class TestRsrReader(unittest.TestCase):
 
         with patch('pyspectral.rsr_reader.get_config', return_value=TEST_CONFIG):
             with self.assertRaises(AttributeError):
-                test_rsr = RelativeSpectralResponse('GOES-16')
-                test_rsr = RelativeSpectralResponse(instrument='ABI')
+                _ = RelativeSpectralResponse('GOES-16')
 
-            test_rsr = RelativeSpectralResponse('GOES-16', 'AbI')
-            self.assertEqual(test_rsr.platform_name, 'GOES-16')
-            self.assertEqual(test_rsr.instrument, 'abi')
-            test_rsr = RelativeSpectralResponse('GOES-16', 'ABI')
-            self.assertEqual(test_rsr.instrument, 'abi')
-
-        with patch('pyspectral.rsr_reader.get_config', return_value=TEST_CONFIG):
-            test_rsr = RelativeSpectralResponse('GOES-16', 'abi')
-
-        self.assertEqual(test_rsr.platform_name, 'GOES-16')
-        self.assertEqual(test_rsr.instrument, 'abi')
-        self.assertEqual(
-            test_rsr.filename, os.path.join(TEST_RSR_DIR, 'rsr_abi_GOES-16.h5'))
-
-        with patch('pyspectral.rsr_reader.get_config', return_value=TEST_CONFIG):
-            test_rsr = RelativeSpectralResponse(
-                filename=os.path.join(TEST_RSR_DIR, 'rsr_abi_GOES-16.h5'))
-
-        self.assertEqual(
-            test_rsr.filename, os.path.join(TEST_RSR_DIR, 'rsr_abi_GOES-16.h5'))
+            with self.assertRaises(AttributeError):
+                _ = RelativeSpectralResponse(instrument='ABI')
 
     @patch('os.path.exists')
     @patch('os.path.isfile')
@@ -241,19 +222,15 @@ class TestPopulateRSRObject(unittest.TestCase):
             _ = RelativeSpectralResponse('MyPlatform')
 
         exception_raised = exec_info.value
-        expected_value = 'platform name and sensor or filename must be specified'
+        expected_value = 'Either platform name and sensor, or filename, must be specified'
         self.assertEqual(str(exception_raised), expected_value)
 
     @patch('pyspectral.rsr_reader.RelativeSpectralResponse.load')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_filename_exist')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._get_filename')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_instrument')
-    def test_set_description(self, check_instrument, get_filename, check_filename_exist, load):
+    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_consistent_input')
+    def test_set_description(self, check_consistent_input, load):
         """Test setting the description."""
         load.return_value = None
-        check_filename_exist.return_value = None
-        get_filename.return_value = None
-        check_instrument.return_value = None
+        check_consistent_input.return_value = None
 
         test_rsr = RelativeSpectralResponse('NOAA-20', 'viirs')
         test_rsr.set_description(self.h5f_noaa20_viirs)
@@ -266,15 +243,11 @@ class TestPopulateRSRObject(unittest.TestCase):
         self.assertEqual(test_rsr.description, 'Relative Spectral Responses for MODIS')
 
     @patch('pyspectral.rsr_reader.RelativeSpectralResponse.load')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_filename_exist')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._get_filename')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_instrument')
-    def test_set_platform_name(self, check_instrument, get_filename, check_filename_exist, load):
+    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_consistent_input')
+    def test_set_platform_name(self, check_consistent_input, load):
         """Test setting the platform name."""
         load.return_value = None
-        check_filename_exist.return_value = None
-        get_filename.return_value = None
-        check_instrument.return_value = None
+        check_consistent_input.return_value = None
 
         test_rsr = RelativeSpectralResponse('EOS-Aqua', 'modis')
         test_rsr.set_platform_name(self.h5f_aqua_modis)
@@ -310,15 +283,11 @@ class TestPopulateRSRObject(unittest.TestCase):
         self.assertEqual(test_rsr.platform_name, None)
 
     @patch('pyspectral.rsr_reader.RelativeSpectralResponse.load')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_filename_exist')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._get_filename')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_instrument')
-    def test_set_instrument(self, check_instrument, get_filename, check_filename_exist, load):
+    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_consistent_input')
+    def test_set_instrument(self, check_consistent_input, load):
         """Test setting the instrument name."""
         load.return_value = None
-        check_filename_exist.return_value = None
-        get_filename.return_value = None
-        check_instrument.return_value = None
+        check_consistent_input.return_value = None
 
         test_rsr = RelativeSpectralResponse('EOS-Aqua', 'modis')
         test_rsr.set_instrument(self.h5f_aqua_modis)
@@ -339,15 +308,11 @@ class TestPopulateRSRObject(unittest.TestCase):
         self.assertEqual(test_rsr.instrument, 'viirs')
 
     @patch('pyspectral.rsr_reader.RelativeSpectralResponse.load')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_filename_exist')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._get_filename')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_instrument')
-    def test_set_band_names(self, check_instrument, get_filename, check_filename_exist, load):
+    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_consistent_input')
+    def test_set_band_names(self, check_consistent_input, load):
         """Test setting the band names."""
         load.return_value = None
-        check_filename_exist.return_value = None
-        get_filename.return_value = None
-        check_instrument.return_value = None
+        check_consistent_input.return_value = None
 
         test_rsr = RelativeSpectralResponse('EOS-Aqua', 'modis')
         test_rsr.set_band_names(self.h5f_aqua_modis)
@@ -355,17 +320,12 @@ class TestPopulateRSRObject(unittest.TestCase):
         self.assertCountEqual(test_rsr.band_names, expected)
 
     @patch('pyspectral.rsr_reader.RelativeSpectralResponse.load')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_filename_exist')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._get_filename')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_instrument')
+    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_consistent_input')
     def test_set_band_central_wavelength_per_detector(self,
-                                                      check_instrument, get_filename,
-                                                      check_filename_exist, load):
+                                                      check_consistent_input, load):
         """Test setting the band specific central wavelength for a detector."""
         load.return_value = None
-        check_filename_exist.return_value = None
-        get_filename.return_value = None
-        check_instrument.return_value = None
+        check_consistent_input.return_value = None
 
         test_rsr = RelativeSpectralResponse('NOAA-20', 'viirs')
 
@@ -381,17 +341,12 @@ class TestPopulateRSRObject(unittest.TestCase):
         self.assertEqual(test_rsr.rsr['M1']['det-1']['central_wavelength'], 100.)
 
     @patch('pyspectral.rsr_reader.RelativeSpectralResponse.load')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_filename_exist')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._get_filename')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_instrument')
+    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_consistent_input')
     def test_set_band_wavelengths_per_detector(self,
-                                               check_instrument, get_filename,
-                                               check_filename_exist, load):
+                                               check_consistent_input, load):
         """Test setting the band wavelengths for a detector."""
         load.return_value = None
-        check_filename_exist.return_value = None
-        get_filename.return_value = None
-        check_instrument.return_value = None
+        check_consistent_input.return_value = None
 
         test_rsr = RelativeSpectralResponse('NOAA-20', 'viirs')
 
@@ -409,17 +364,12 @@ class TestPopulateRSRObject(unittest.TestCase):
         assertNumpyArraysEqual(test_rsr.rsr['M1']['det-1']['wavelength'].data, expected)
 
     @patch('pyspectral.rsr_reader.RelativeSpectralResponse.load')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_filename_exist')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._get_filename')
-    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_instrument')
+    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_consistent_input')
     def test_set_band_responses_per_detector(self,
-                                             check_instrument, get_filename,
-                                             check_filename_exist, load):
+                                             check_consistent_input, load):
         """Test setting the band responses for a detector."""
         load.return_value = None
-        check_filename_exist.return_value = None
-        get_filename.return_value = None
-        check_instrument.return_value = None
+        check_consistent_input.return_value = None
 
         test_rsr = RelativeSpectralResponse('NOAA-20', 'viirs')
 
@@ -435,6 +385,20 @@ class TestPopulateRSRObject(unittest.TestCase):
         expected = np.array([0, 1, 2, 3, 4, 5, 6, 7, 8, 9])
         assertNumpyArraysEqual(test_rsr.rsr['M1']['det-1']['response'].data, expected)
 
+    @patch('pyspectral.rsr_reader.RelativeSpectralResponse.load')
+    @patch('pyspectral.rsr_reader.RelativeSpectralResponse._check_consistent_input')
+    def test_get_bandname_from_rsr(self,
+                                   check_consistent_input, load):
+        """Test get the matching band name from the rsr object."""
+        load.return_value = None
+        check_consistent_input.return_value = None
+
+        test_rsr = RelativeSpectralResponse('EOS-Aqua', 'modis')
+        test_rsr.rsr = TEST_RSR
+
+        myband = test_rsr.get_bandname_from_wavelength(3.75)
+        assert myband == '20'
+
     def test_rsr_dict(self):
         """Test finding correct band names from utils dicts."""
         test_rsr = RSRDict(instrument='viirs')
@@ -449,3 +413,95 @@ class TestPopulateRSRObject(unittest.TestCase):
         # Check exception raised if incorrect band name given
         with self.assertRaises(KeyError):
             print('d', test_rsr['VIS030'])
+
+    def test_rsr_unconfigured_sensor(self):
+        """Test RSRDict finds generic band conversions when specific sensor is not configured."""
+        test_rsr = RSRDict(instrument="i dont exist")
+        test_rsr["ch1"] = 2
+        assert test_rsr['1'] == 2
+
+
+@patch('os.path.exists')
+@patch('os.path.isfile')
+@patch('pyspectral.rsr_reader.RelativeSpectralResponse.load')
+@patch('pyspectral.rsr_reader.download_rsr')
+@patch('pyspectral.rsr_reader.RelativeSpectralResponse._get_rsr_data_version')
+@pytest.mark.parametrize(
+    ("platform_name", "instrument", "exp_filename", "exp_instrument"),
+    [
+        ('FY-3D', 'mersi-2', 'rsr_mersi2_FY-3D.h5', 'mersi2'),
+        ('TIROS-N', 'avhrr-1', 'rsr_avhrr1_TIROS-N.h5', 'avhrr1'),
+        ('NOAA-12', 'avhrr-2', 'rsr_avhrr2_NOAA-12.h5', 'avhrr2'),
+        ('NOAA-12', 'avhrr/2', 'rsr_avhrr2_NOAA-12.h5', 'avhrr2'),
+        ('NOAA-19', 'avhrr/3', 'rsr_avhrr3_NOAA-19.h5', 'avhrr3'),
+        ('GOES-16', 'abi', 'rsr_abi_GOES-16.h5', 'abi'),
+        ('GOES-16', 'ABI', 'rsr_abi_GOES-16.h5', 'abi'),
+        ('GOES-18', 'AbI', 'rsr_abi_GOES-18.h5', 'abi'),
+    ]
+)
+def test_get_rsr_from_platform_and_instrument(get_rsr_version,
+                                              download_rsr, load, isfile, exists,
+                                              platform_name, instrument,
+                                              exp_filename, exp_instrument):
+    """Test getting the rsr filename correct when specifying the platform and instrument names."""
+    load.return_code = None
+    download_rsr.return_code = None
+    isfile.return_code = True
+    exists.return_code = True
+    get_rsr_version.return_code = RSR_DATA_VERSION
+
+    with patch('pyspectral.rsr_reader.get_config', return_value=TEST_CONFIG):
+        test_rsr = RelativeSpectralResponse(platform_name, instrument)
+        assert test_rsr.platform_name == platform_name
+        assert test_rsr.instrument == exp_instrument
+        assert os.path.basename(test_rsr.filename) == exp_filename
+
+    # def test_get_bandname_from_wavelength_inconsistent_instrument_name(self):
+    #     """Test the right bandname is found provided the wavelength in micro meters.
+
+    #     Here we test that if you enter with a sensor name different from what
+    #     is set in the RSR object, an error is raised.
+
+    #     """
+    #     with pytest.raises(AttributeError):
+    #         bname = utils.get_bandname_from_wavelength('ahi', 0.4, self.rsr)
+
+
+@pytest.mark.parametrize(
+    ("version", "exp_download"),
+    [
+        (RSR_DATA_VERSION, False),
+        ("v1.0.0", True),
+    ],
+)
+def test_check_and_download(tmp_path, version, exp_download):
+    """Test that check_and_download only downloads when necessary."""
+    from pyspectral.rsr_reader import check_and_download
+    with _fake_rsr_dir(tmp_path, version), unittest.mock.patch("pyspectral.rsr_reader.download_rsr") as download:
+        check_and_download()
+        if exp_download:
+            download.assert_called()
+        else:
+            download.assert_not_called()
+
+
+@contextlib.contextmanager
+def _fake_rsr_dir(tmp_path, rsr_version):
+    with _fake_get_config(tmp_path):
+        version_filename = str(tmp_path / RSR_DATA_VERSION_FILENAME)
+        with open(version_filename, "w") as version_file:
+            version_file.write(rsr_version)
+        yield
+
+
+@contextlib.contextmanager
+def _fake_get_config(tmp_path):
+    def _get_config():
+        return {
+            "rayleigh_dir": str(tmp_path),
+            "rsr_dir": str(tmp_path),
+            "download_from_internet": True,
+        }
+    with unittest.mock.patch("pyspectral.rsr_reader.get_config") as get_config:
+        get_config.side_effect = _get_config
+        yield
