@@ -28,3 +28,21 @@ def assertNumpyArraysEqual(self, other):
         raise AssertionError("Shapes don't match")
     if not np.allclose(self, other):
         raise AssertionError("Elements don't match!")
+
+
+class ComputeCountingScheduler:
+    """Scheduler raising an exception if data are computed too many times."""
+
+    def __init__(self, max_computes=1):
+        """Set starting and maximum compute counts."""
+        self.max_computes = max_computes
+        self.total_computes = 0
+
+    def __call__(self, dsk, keys, **kwargs):
+        """Compute dask task and keep track of number of times we do so."""
+        import dask
+        self.total_computes += 1
+        if self.total_computes > self.max_computes:
+            raise RuntimeError("Too many dask computations were scheduled: "
+                               "{}".format(self.total_computes))
+        return dask.get(dsk, keys, **kwargs)
